within FluidDissipation.Examples.Verifications.PressureLoss;
package HeatExchanger
  extends FluidDissipation.Utilities.Icons.ExamplesLibrary;

  model dp_flatTube_DP "Verification of function dp_flatTube_DP"
    import FluidDissipation;

    parameter Integer n=2 "Number of various fin geometries";

    //heat exchanger variables
    parameter SI.Area A_fr=0.1 "Frontal area";

    //heat exchanger variables geometry no.1

    parameter SI.Length D_m_1=0.005 "Major tube diameter for flat tube";
    parameter SI.Length F_l_1=0.019 "Fin length";
    parameter SI.Length F_d_1=0.026 "Fin depth";
    parameter SI.Length F_p_1=0.0018 "Fin pitch, fin spacing + fin thickness";
    parameter SI.Length L_1=F_d_1 "Heat exchanger length";
    parameter SI.Length L_l_1=0.01607 "Louver length";
    parameter SI.Length L_p_1=0.001534 "Louver pitch";
    parameter SI.Length T_p_1=0.0197 "Tube pitch";

    parameter SI.Length delta_f_1=0.0001 "Fin thickness";

    parameter SI.Angle Phi_1=28*PI/180 "Louver angle";

    //heat exchanger variables geometry no.2
    parameter SI.Length D_h_2=0.002383 "Hydraulic diameter";
    parameter SI.Length D_m_2=0.002 "Major tube diameter for flat tube";
    parameter SI.Length L_2=0.025 "Heat exchanger length";
    parameter Real alpha_2=0.244
      "Lateral fin spacing (s) / free flow height (h)";
    parameter Real gamma_2=0.067 "Fin thickness (t) / lateral fin spacing (s)";
    parameter Real delta_2=0.032 "Fin thickness (t) / fin length (l)";

    //fluid property variables
    SI.DynamicViscosity eta=1e-3 "Dynamic viscosity of fluid";
    SI.Density rho=1000 "Density of fluid";

    //input VARIABLES
    SI.ReynoldsNumber Re=input_Re.y "Reynolds number"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_1=abs(Re)*eta*A_c[1]/L_p_1 "mass flow"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_2=abs(Re)*eta*A_c[2]/D_h_2 "mass flow"
      annotation (Dialog(group="Input"));

    //output variables
    SI.Pressure DP[n] "Pressure loss" annotation (Dialog(group="Output"));
    Real zeta_TOT[n]={2*abs(DP[i])/(max(rho*(v_c[i])^2, MIN)) for i in 1:n}
      "Pressure loss coefficients" annotation (Dialog(group="Output"));
    Real lambda_FRI[n]={zeta_TOT[i]*D_h[i]/L[i] for i in 1:n}
      "Frictional resistance coefficient";

  protected
    constant Real MIN=Modelica.Constants.eps;

    SI.Velocity v_c[n]={abs(Re)*eta/(rho*L_p_1),abs(Re)*eta/(rho*D_h_2)}
      "Velocity at minimum flow cross-sectional area";

    SI.Area A_c[n]={A_fr*((F_l_1 - delta_f_1)*(F_p_1 - delta_f_1)/((F_l_1 +
        D_m_1)*F_p_1)),A_fr*(h_2*s_2/((h_2 + t_2 + D_m_2)*(s_2 + t_2)))}
      "Minimum flow cross-sectional area";

    SI.Length D_h[n]={4*A_c[1]/(A_fr*(2*(F_p_1 - delta_f_1 + F_l_1 - delta_f_1)
        /(F_p_1*(F_l_1 + D_m_1)))),D_h_2} "Hydraulic diameter";

    SI.Length L[n]={L_1,L_2} "Heat exchanger length";

    SI.Length h_2=D_h_2*(1 + alpha_2)/(2*alpha_2) "Free flow height";
    SI.Length l_2=t_2/delta_2 "Fin length";
    SI.Length s_2=h_2*alpha_2 "Lateral fin spacing (free flow width)";
    SI.Length t_2=s_2*gamma_2 "Fin thickness";

    FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_IN_con
      m_flow_IN_con_1(
      A_fr=A_fr,
      D_m=D_m_1,
      F_d=F_d_1,
      F_l=F_l_1,
      F_p=F_p_1,
      L_l=L_l_1,
      L_p=L_p_1,
      T_p=T_p_1,
      Phi=Phi_1,
      geometry=1,
      L=L_1,
      delta_f=delta_f_1)
      annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_IN_var
      m_flow_IN_var_1(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{-40,-20},{-20,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_IN_con
      m_flow_IN_con_2(
      geometry=2,
      A_fr=A_fr,
      D_h=D_h_2,
      D_m=D_m_2,
      alpha=alpha_2,
      gamma=gamma_2,
      delta=delta_2,
      L=L_2) annotation (Placement(transformation(extent={{20,-20},{40,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_IN_var
      m_flow_IN_var_2(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{40,-20},{60,0}})));
  public
    Modelica.Blocks.Sources.Ramp input_Re(
      duration=1,
      startTime=0,
      height=10000,
      offset=0) annotation (extent=[-80, -80; -60, -60], Placement(
          transformation(extent={{-80,-80},{-60,-60}})));
  equation
    //target == DP (incompressible)
    DP[1] = FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_DP(
        m_flow_IN_con_1,
        m_flow_IN_var_1,
        m_flow_1);

    DP[2] = FluidDissipation.PressureLoss.HeatExchanger.dp_flatTube_DP(
        m_flow_IN_con_2,
        m_flow_IN_var_2,
        m_flow_2);

    annotation (Commands(file=
            "modelica://FluidDissipation/Extras/Scripts/pressureLoss/heatExchanger/dp_flatTube_DP.mos"
          "Verification of dp_flatTube_DP"), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
          graphics={Text(
              extent={{-58,-22},{-22,-30}},
              lineColor={0,0,255},
              textString="Flat tube and louver fin"),Text(
              extent={{22,-22},{58,-30}},
              lineColor={0,0,255},
              textString="Flat tube and slit fin"),Text(
              extent={{-100,50},{100,75}},
              lineColor={0,0,255},
              textString=
              "Pressure loss of heat exchangers with flat tubes and various fin geometries")}));
  end dp_flatTube_DP;

  model dp_roundTube_DP "Verification of function dp_roundTube_DP"
    import FluidDissipation;

    parameter Integer n=4 "Number of various fin geometries";

    //heat exchanger variables
    parameter SI.Area A_fr=0.1 "Frontal area";

    //heat exchanger variables geometry no.1

    parameter SI.Length D_c_1=0.01023 "Fin collar diameter";
    parameter SI.Length F_p_1=0.00177 "Fin pitch, fin spacing + fin thickness";
    parameter SI.Length L_1=N_1*P_l_1 "Heat exchanger length";
    parameter Integer N_1=2 "Number of tube rows";
    parameter SI.Length P_l_1=0.022 "Longitudinal tube pitch";
    parameter SI.Length P_t_1=0.0254 "Transverse tube pitch";

    parameter SI.Length delta_f_1=0.0002 "Fin thickness";

    //heat exchanger variables geometry no.2

    parameter SI.Length D_c_2=0.01042 "Fin collar diameter";
    parameter SI.Length F_p_2=0.00205 "Fin pitch, fin spacing + fin thickness";
    parameter SI.Length L_2=N_2*P_l_2 "Heat exchanger length";
    parameter SI.Length L_h_2=0.0014 "Louver height";
    parameter SI.Length L_p_2=0.0024 "Louver pitch";
    parameter Integer N_2=2 "Number of tube rows";
    parameter SI.Length P_l_2=0.01905 "Longitudinal tube pitch";
    parameter SI.Length P_t_2=0.0254 "Transverse tube pitch";

    parameter SI.Length delta_f_2=0.0001 "Fin thickness";

    //heat exchanger variables geometry no.3

    parameter SI.Length D_c_3=0.01034 "Fin collar diameter";
    parameter SI.Length F_p_3=0.00246 "Fin pitch, fin spacing + fin thickness";
    parameter SI.Length L_3=N_3*P_l_3 "Heat exchanger length";
    parameter Integer N_3=2 "Number of tube rows";
    parameter SI.Length P_l_3=0.022 "Longitudinal tube pitch";
    parameter SI.Length P_t_3=0.0254 "Transverse tube pitch";

    parameter SI.Length delta_f_3=0.00012 "Fin thickness";

    //heat exchanger variables geometry no.4

    parameter SI.Length D_c_4=0.0103 "Fin collar diameter";
    parameter SI.Length F_p_4=0.00169 "Fin pitch, fin spacing + fin thickness";
    parameter SI.Length L_4=N_4*P_l_4 "Heat exchanger length";
    parameter Integer N_4=2 "Number of tube rows";
    parameter SI.Length P_d_4=0.0015 "Pattern depth of wavy fin, wave height";
    parameter SI.Length P_l_4=0.01905 "Longitudinal tube pitch";
    parameter SI.Length P_t_4=0.0254 "Transverse tube pitch";
    parameter SI.Length X_f_4=0.0047625 "Half wave length of wavy fin";

    parameter SI.Length delta_f_4=0.0001 "Fin thickness";

    //fluid property variables
    SI.DynamicViscosity eta=1e-3 "Dynamic viscosity of fluid";
    SI.Density rho=1000 "Density of fluid";

    //input VARIABLES
    SI.ReynoldsNumber Re=input_Re.y "Reynolds number"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_1=abs(Re)*eta*A_c[1]/D_c_1 "mass flow"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_2=abs(Re)*eta*A_c[2]/D_c_2 "mass flow"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_3=abs(Re)*eta*A_c[3]/D_c_3 "mass flow"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow_4=abs(Re)*eta*A_c[4]/D_c_4 "mass flow"
      annotation (Dialog(group="Input"));

    //output variables
    SI.Pressure DP[n] "Pressure loss" annotation (Dialog(group="Output"));
    Real zeta_TOT[n]={2*abs(DP[i])/(max(rho*(v_c[i])^2, MIN)) for i in 1:n}
      "Pressure loss coefficients" annotation (Dialog(group="Output"));
    Real lambda_FRI[n]={zeta_TOT[i]*D_h[i]/L[i] for i in 1:n}
      "Frictional resistance coefficient";

  protected
    constant Real MIN=Modelica.Constants.eps;

    SI.Velocity v_c[n]={abs(Re)*eta/(rho*D_c_1),abs(Re)*eta/(rho*D_c_2),abs(Re)
        *eta/(rho*D_c_3),abs(Re)*eta/(rho*D_c_4)}
      "Velocity at minimum flow cross-sectional area";

    SI.Area A_c[n]={A_fr*((F_p_1*P_t_1 - F_p_1*D_c_1 - (P_t_1 - D_c_1)*
        delta_f_1)/(F_p_1*P_t_1)),A_fr*((F_p_2*P_t_2 - F_p_2*D_c_2 - (P_t_2 -
        D_c_2)*delta_f_2)/(F_p_2*P_t_2)),A_fr*((F_p_3*P_t_3 - F_p_3*D_c_3 - (
        P_t_3 - D_c_3)*delta_f_3)/(F_p_3*P_t_3)),A_fr*((F_p_4*P_t_4 - F_p_4*
        D_c_4 - (P_t_4 - D_c_4)*delta_f_4)/(F_p_4*P_t_4))}
      "Minimum flow cross-sectional area";

    SI.Area A_tot[n]={A_fr*((N_1*PI*D_c_1*(F_p_1 - delta_f_1) + 2*(P_t_1*L_1 -
        N_1*PI*D_c_1^2/4))/(P_t_1*F_p_1)),A_fr*((N_2*PI*D_c_2*(F_p_2 -
        delta_f_2) + 2*(P_t_2*L_2 - N_2*PI*D_c_2^2/4))/(P_t_2*F_p_2)),A_fr*((
        N_3*PI*D_c_3*(F_p_3 - delta_f_3) + 2*(P_t_3*L_3 - N_3*PI*D_c_3^2/4))/(
        P_t_3*F_p_3)),A_fr*((N_4*PI*D_c_4*(F_p_4 - delta_f_4) + 2*(P_t_4*L_4 -
        N_4*PI*D_c_4^2/4)*(sqrt(X_f_4^2 + P_d_4^2)/X_f_4))/(P_t_4*F_p_4))}
      "Total heat transfer area";

    SI.Length D_h[n]={4*A_c[i]*L[i]/A_tot[i] for i in 1:n} "Hydraulic diameter";

    SI.Length L[n]={L_1,L_2,L_3,L_4} "Heat exchanger length";

    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_con
      m_flow_IN_con_1(
      geometry=1,
      A_fr=A_fr,
      D_c=D_c_1,
      F_p=F_p_1,
      N=N_1,
      P_t=P_t_1,
      L=L_1,
      delta_f=delta_f_1,
      P_l=P_l_1)
      annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_con
      m_flow_IN_con_2(
      geometry=2,
      A_fr=A_fr,
      D_c=D_c_2,
      F_p=F_p_2,
      L_h=L_h_2,
      L_p=L_p_2,
      N=N_2,
      P_l=P_l_2,
      P_t=P_t_2,
      L=L_2,
      delta_f=delta_f_2)
      annotation (Placement(transformation(extent={{20,20},{40,40}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_con
      m_flow_IN_con_3(
      geometry=3,
      A_fr=A_fr,
      D_c=D_c_3,
      F_p=F_p_3,
      N=N_3,
      P_l=P_l_3,
      P_t=P_t_3,
      L=L_3,
      delta_f=delta_f_3)
      annotation (Placement(transformation(extent={{-60,-40},{-40,-20}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_con
      m_flow_IN_con_4(
      geometry=4,
      A_fr=A_fr,
      D_c=D_c_4,
      F_p=F_p_4,
      N=N_4,
      P_d=P_d_4,
      P_t=P_t_4,
      X_f=X_f_4,
      L=L_4,
      delta_f=delta_f_4)
      annotation (Placement(transformation(extent={{20,-40},{40,-20}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_var
      m_flow_IN_var_1(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{-40,20},{-20,40}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_var
      m_flow_IN_var_2(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{40,20},{60,40}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_var
      m_flow_IN_var_3(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{-40,-40},{-20,-20}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_IN_var
      m_flow_IN_var_4(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{40,-40},{60,-20}})));
  public
    Modelica.Blocks.Sources.Ramp input_Re(
      duration=1,
      startTime=0,
      height=10000,
      offset=0) annotation (extent=[-80, -80; -60, -60], Placement(
          transformation(extent={{-80,-80},{-60,-60}})));
  equation
    //target == DP (incompressible)
    DP[1] = FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_DP(
        m_flow_IN_con_1,
        m_flow_IN_var_1,
        m_flow_1);

    DP[2] = FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_DP(
        m_flow_IN_con_2,
        m_flow_IN_var_2,
        m_flow_2);

    DP[3] = FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_DP(
        m_flow_IN_con_3,
        m_flow_IN_var_3,
        m_flow_3);

    DP[4] = FluidDissipation.PressureLoss.HeatExchanger.dp_roundTube_DP(
        m_flow_IN_con_4,
        m_flow_IN_var_4,
        m_flow_4);

    annotation (Commands(file=
            "modelica://FluidDissipation/Extras/Scripts/pressureLoss/heatExchanger/dp_roundTube_DP.mos"
          "Verification of dp_roundTube_DP"), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
          graphics={Text(
              extent={{-100,50},{100,75}},
              lineColor={0,0,255},
              textString=
              "Pressure loss of heat exchangers with round tubes and various fin geometries")}));
  end dp_roundTube_DP;

  model dp_corrugatedPlate_1ph_DP
    "Verification of function dp_corrugatedPlate_1ph_DP"
    import FluidDissipation;

    parameter Integer n=3 "Number of various plate geometries";

    parameter Integer channels(min = 1) = 1
      "number of paralell flown channels per fluid";
    parameter SI.Length Length(min=1e-2)=0.3
      "length of the heat exchanger plates in flow direction (header center to header center)";
    parameter SI.Length Width(min=1e-2)=0.1
      "width of the heat exchanger plates in flow direction";
    parameter SI.Length amp(min=1e-10) = 2e-3 "amplitude of corrugated plate";
    parameter SI.Length Lambda(min=1e-10) = 2*Modelica.Constants.pi*amp
      "wave length of corrugated plate";
    parameter SI.Conversions.NonSIunits.Angle_deg[n] phi = {30, 45, 60}*Modelica.Constants.pi/180
      "Corrugation angle";

    //fluid property variables
    SI.DynamicViscosity eta=1e-3 "Dynamic viscosity of fluid";
    SI.Density rho=1000 "Density of fluid";

    //input VARIABLES
    SI.ReynoldsNumber Re=input_Re.y "Reynolds number"
      annotation (Dialog(group="Input"));
    SI.ReynoldsNumber m_flow=abs(Re)*eta*A_c/D_h "mass flow"
      annotation (Dialog(group="Input"));

    //output variables
    SI.Pressure DP[n] "Pressure loss" annotation (Dialog(group="Output"));
    Real zeta_TOT[n]={2*abs(DP[i])/(max(rho*(w)^2, MIN)) for i in 1:n}
      "Pressure loss coefficients" annotation (Dialog(group="Output"));
    Real lambda_FRI[n]={zeta_TOT[i]*D_h/Length for i in 1:n}
      "Frictional resistance coefficient";

  protected
    constant Real MIN=Modelica.Constants.eps;

    SI.Velocity w=abs(Re)*eta/(rho*D_h) "Velocity";
    SI.Area A_c=channels*2*amp*Width "Flow cross-sectional area";
    SI.Length D_h=4*amp/Phi "Hydraulic diameter";

    Real X = 2*Modelica.Constants.pi*amp/Lambda "wave number";
    Real Phi = 1/6*(1+sqrt(1+X^2)+4*sqrt(1+0.5*X^2)) "area enhancement factor";

  public
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_con
      m_flow_IN_con_1(
      channels=channels,
      Length=Length,
      Width=Width,
      amp=amp,
      phi=phi[1])
      annotation (Placement(transformation(extent={{-80,-20},{-60,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_var
      m_flow_IN_var_1(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_con
      m_flow_IN_con_2(
      channels=channels,
      Length=Length,
      Width=Width,
      amp=amp,
      phi=phi[2])
      annotation (Placement(transformation(extent={{-20,-20},{0,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_var
      m_flow_IN_var_2(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{0,-20},{20,0}})));
  public
    Modelica.Blocks.Sources.Ramp input_Re(
      duration=1,
      startTime=0,
      height=10000,
      offset=0) annotation (extent=[-80, -80; -60, -60], Placement(
          transformation(extent={{-80,-80},{-60,-60}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_con
      m_flow_IN_con_3(
      channels=channels,
      Length=Length,
      Width=Width,
      amp=amp,
      phi=phi[3])
      annotation (Placement(transformation(extent={{40,-20},{60,0}})));
    FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_IN_var
      m_flow_IN_var_3(eta=eta, rho=rho)
      annotation (Placement(transformation(extent={{60,-20},{80,0}})));
  equation
    //target == DP (incompressible)
    DP[1] = FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_DP(
        m_flow_IN_con_1,
        m_flow_IN_var_1,
        m_flow);

    DP[2] = FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_DP(
        m_flow_IN_con_2,
        m_flow_IN_var_2,
        m_flow);

    DP[3] = FluidDissipation.PressureLoss.HeatExchanger.dp_corrugatedPlate_1ph_DP(
        m_flow_IN_con_3,
        m_flow_IN_var_3,
        m_flow);

    annotation (Commands(file=
            "modelica://FluidDissipation/Extras/Scripts/pressureLoss/heatExchanger/dp_flatTube_DP.mos"
          "Verification of dp_flatTube_DP"), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
          graphics={                               Text(
              extent={{-100,56},{100,66}},
              lineColor={0,0,255},
            textString="Pressure loss of corrugated plate heat exchanger")}));
  end dp_corrugatedPlate_1ph_DP;
end HeatExchanger;
